in_toolchain

Function in_toolchain 

pub fn in_toolchain(program: impl AsRef<OsStr>) -> Result<Command>
Build a command that calls the given binary in the correct toolchain environment. This uses rustup to provide the correct toolchain, unless we’re in a nix context where the toolchain is already in PATH.